@@ -195,8 +195,15 @@ def _call_remote_broker_agent(username, task, cmdline_args=[], remote_agent=None
 
     if remote_agent is None:
         logger_error.error('With the SSH agent-query-mode a remote agent host (hostname, hostaddr, port) has to be specified!')
-    elif 'host_key_policy' not in remote_agent:
-        remote_agent['host_key_policy'] = paramiko.WarningPolicy()
+    elif 'host_key_policy' not in remote_agent or remote_agent['host_key_policy'] == 'WarningPolicy':
+        _hostkey_policy = paramiko.WarningPolicy()
+    elif remote_agent['host_key_policy'] == 'RejectPolicy':
+        _hostkey_policy = paramiko.RejectPolicy()
+    elif remote_agent['host_key_policy'] == 'AutoAddPolicy':
+        _hostkey_policy = paramiko.AutoAddPolicy()
+    else:
+        logger_error.error('Invalid SSH HostKey Policy: "{policy}", falling back to "RejectPolicy"!'.format(policy=remote_agent['host_key_policy']))
+        _hostkey_policy = paramiko.RejectPolicy()
 
     remote_hostaddr = None
     remote_hostname = None
@@ -237,7 +244,7 @@ def _call_remote_broker_agent(username, task, cmdline_args=[], remote_agent=None
             client.load_system_host_keys()
             if os.path.exists(os.path.expanduser("~/.ssh/known_hosts")):
                 client.load_host_keys(os.path.expanduser("~/.ssh/known_hosts"))
-            client.set_missing_host_key_policy(remote_agent['host_key_policy'])
+            client.set_missing_host_key_policy(_hostkey_policy)
             client.connect(_remote_sshserver, remote_port, remote_username, look_for_keys=True, allow_agent=True)
 
             result = []
