@@ -82,6 +82,7 @@ class X2GoBroker(object):
 
         self._dynamic_cookie_map = {}
         self._client_address = None
+        self._cookie = None
 
     def __del__(self):
         """\
@@ -199,6 +200,8 @@ class X2GoBroker(object):
         my_cookie = unconfigured_my_cookie
 
         deprecated_my_cookie = self.config.get_value('global', 'my-cookie')
+        if deprecated_my_cookie is None:
+            deprecated_my_cookie = uuid.uuid4()
         my_cookie_file = self.config.get_value('global', 'my-cookie-file')
 
         if os.path.isfile(my_cookie_file):
@@ -559,6 +562,44 @@ class X2GoBroker(object):
         else:
             return _mode
 
+    def get_agent_hostkey_policy(self, profile_id):
+        """\
+        Get the agent hostkey policy (either of 'RejectPolicy',
+        'AutoAddPolicy' or 'WarningPolicy') that is configured for this
+        X2Go Session Broker instance.
+
+        The returned policy names match the MissingHostkeyPolicy class
+        names as found in Python Paramiko.
+
+        :returns: agent hostkey policy
+        :rtype: ``str``
+
+        """
+        _default_agent_hostkey_policy = "RejectPolicy"
+        _backend_agent_hostkey_policy = ""
+        _agent_hostkey_policy = ""
+
+        _profile = self.get_profile_broker(profile_id)
+        if _profile and 'broker-agent-hostkey-policy' in _profile and _profile['broker-agent-hostkey-policy']:
+            _agent_hostkey_policy = _profile['broker-agent-hostkey-policy']
+            logger_broker.debug('base_broker.X2GoBroker.get_agent_hostkey_policy(): found broker-agent-hostkey-policy in session profile with ID {id}: {value}. This one has precendence over the default and the backend value.'.format(id=profile_id, value=_agent_hostkey_policy))
+
+        elif self.config.has_value('broker_{backend}'.format(backend=self.backend_name), 'agent-hostkey-policy') and self.config.get_value('broker_{backend}'.format(backend=self.backend_name), 'agent-hostkey-policy'):
+            _backend_agent_hostkey_policy = self.config.get_value('broker_{backend}'.format(backend=self.backend_name), 'agent-hostkey-policy')
+            logger_broker.debug('base_broker.X2GoBroker.get_agent_hostkey_policy(): found agent-hostkey-policy in backend config section »{backend}«: {value}. This one has precendence over the default value.'.format(backend=self.backend_name, value=_agent_hostkey_policy))
+
+        elif self.config.has_value('global', 'default-agent-hostkey-policy') and self.config.get_value('global', 'default-agent-hostkey-policy'):
+            _default_agent_hostkey_policy = self.config.get_value('global', 'default-agent-hostkey-policy')
+            logger_broker.debug('base_broker.X2GoBroker.get_agent_hostkey_policy(): found default-agent-hostkey-policy in global config section: {value}'.format(value=_default_agent_hostkey_policy))
+
+        _policy = _agent_hostkey_policy or _backend_agent_hostkey_policy or _default_agent_hostkey_policy
+
+        if _policy not in ('AutoAddPolicy', 'RejectPolicy', 'WarningPolicy'):
+            logger_broker.warn('base_broker.X2GoBroker.get_agent_hostkey_policy(): given hostkey policy ({policy}) is invalid/unknown, falling back to default hostkey policy ({default_policy}).'.format(policy=_policy, default_policy=_default_agent_hostkey_policy))
+            _policy = _default_agent_hostkey_policy
+
+        return _policy
+
     def get_session_autologin(self, profile_id):
         """\
         Detect if the given profile is configured to try automatic session
@@ -981,9 +1022,8 @@ class X2GoBroker(object):
                 ###
                 ###
 
-                logger_broker.debug('base_broker.X2GoBroker.check_access(): checking for valid authentication: {access}'.format(access=access))
-
                 if access:
+                    logger_broker.warning('base_broker.X2GoBroker.check_access(): authentication succeeded for user {username} at ip {ip}'.format(username=username, ip=ip))
                     #create new cookie for this user
                     #each user gets one or more tuples of IP, time stored as username_UUID files so they can connect from multiple sessions
                     next_cookie = str(uuid.uuid4())
@@ -994,6 +1034,8 @@ class X2GoBroker(object):
                     if cookie_directory and username and cookie:
                         os.remove(cookie_directory+"/"+username+"_"+cookie)
                     logger_broker.debug('base_broker.X2GoBroker.check_access(): Giving new cookie: {cookie} to user {username} at ip {ip}'.format(cookie=next_cookie,username=username,ip=ip))
+                else:
+                    logger_broker.warning('base_broker.X2GoBroker.check_access(): authentication failed for user {username} at ip {ip}'.format(username=username, ip=ip))
 
             else:
                 # there is a cookie but its not ours so its either wrong or subsequent password auth
@@ -1092,7 +1134,9 @@ class X2GoBroker(object):
                 remote_agent = {
                     'hostname': remote_agent_hostname,
                     'hostaddr': remote_agent_hostaddr,
-                    'port': remote_agent_port, }
+                    'port': remote_agent_port,
+                    'host_key_policy': self.get_agent_hostkey_policy(profile_id),
+                }
 
                 try:
                     if x2gobroker.agent.ping(remote_agent=remote_agent):
