@@ -110,23 +110,39 @@ host = host1.mydomain, host2.yourdomain
 name = testprofile5
 host = host1.mydomain (10.0.2.4), host2.mydomain (10.0.2.5)
 broker-agent-query-mode = SSH
+broker-agent-hostkey-policy = WarningPolicy
 
 [testprofile6]
 name = testprofile6
 host = host1.mydomain (10.0.2.4), host2.mydomain (10.0.2.5)
 sshport = 23467
 broker-agent-query-mode = SSH
+broker-agent-hostkey-policy = WarningPolicy
 
 [testprofile7]
 name = testprofile7
 host = docker-vm-1 (docker-server:22001), docker-vm-2 (docker-server:22002)
 broker-agent-query-mode = SSH
+broker-agent-hostkey-policy = WarningPolicy
 
 [testprofile8]
 name = testprofile8
 host = docker-vm-0 (docker-server), docker-vm-1 (docker-server:22001), docker-vm-2 (docker-server:22002)
 sshport = 22000
 broker-agent-query-mode = SSH
+broker-agent-hostkey-policy = WarningPolicy
+
+[testprofile9]
+name = testprofile9
+host = host1.mydomain (10.0.2.4)
+broker-agent-query-mode = SSH
+broker-agent-hostkey-policy = AutoAddPolicy
+
+[testprofile10]
+name = testprofile10
+host = host1.mydomain (10.0.2.4)
+broker-agent-query-mode = SSH
+broker-agent-hostkey-policy = SomeUnkownPolicy
 
 """
         tf = tempfile.NamedTemporaryFile(mode='w')
@@ -207,7 +223,7 @@ broker-agent-query-mode = SSH
         i = 0
         while i < 10:
             _remoteagent5 = inifile_backend.get_remote_agent('testprofile5')
-            self.assertTrue( _remoteagent5 == {'hostname': 'host1.mydomain', 'hostaddr': '10.0.2.4', 'port': 22, 'load_factors': {}, } or _remoteagent5 == {'hostname': 'host2.mydomain', 'hostaddr': '10.0.2.5', 'port': 22, 'load_factors': {}, } )
+            self.assertTrue( _remoteagent5 == {'hostname': 'host1.mydomain', 'hostaddr': '10.0.2.4', 'port': 22, 'load_factors': {}, 'host_key_policy': 'WarningPolicy'} or _remoteagent5 == {'hostname': 'host2.mydomain', 'hostaddr': '10.0.2.5', 'port': 22, 'load_factors': {}, 'host_key_policy': 'WarningPolicy', } )
             _session5 = inifile_backend.select_session('testprofile5', 'foo5N')
             self.assertTrue( _session5 == {'port': 22, 'server': '10.0.2.4', } or _session5 == {'port': 22, 'server': '10.0.2.5', } )
             i += 1
@@ -221,7 +237,7 @@ broker-agent-query-mode = SSH
         self.assertTrue( _profile6['host'][0] in ('host1.mydomain', 'host2.mydomain') )
         self.assertTrue( 'status' not in _profile6 )
         _remoteagent6 = inifile_backend.get_remote_agent('testprofile6')
-        self.assertTrue( _remoteagent6 == {'hostname': 'host1.mydomain', 'hostaddr': '10.0.2.4', 'port': 23467, 'load_factors': {}, } or _remoteagent6 == {'hostname': 'host2.mydomain', 'hostaddr': '10.0.2.5', 'port': 23467, 'load_factors': {}, } )
+        self.assertTrue( _remoteagent6 == {'hostname': 'host1.mydomain', 'hostaddr': '10.0.2.4', 'port': 23467, 'load_factors': {}, 'host_key_policy': 'WarningPolicy', } or _remoteagent6 == {'hostname': 'host2.mydomain', 'hostaddr': '10.0.2.5', 'port': 23467, 'load_factors': {}, 'host_key_policy': 'WarningPolicy', } )
         _session6 = inifile_backend.select_session('testprofile6', 'foo6N')
         self.assertTrue( _session6 == {'port': 23467, 'server': '10.0.2.4', } or _session6 == {'port': 23467, 'server': '10.0.2.5', } )
 
@@ -233,7 +249,7 @@ broker-agent-query-mode = SSH
         i = 0
         while i < 10:
             _remoteagent7 = inifile_backend.get_remote_agent('testprofile7')
-            self.assertTrue( _remoteagent7 == {'hostname': 'docker-vm-1', 'hostaddr': 'docker-server', 'port': 22001, 'load_factors': {}, } or _remoteagent7 == {'hostname': 'docker-vm-2', 'hostaddr': 'docker-server', 'port': 22002, 'load_factors': {}, } )
+            self.assertTrue( _remoteagent7 == {'hostname': 'docker-vm-1', 'hostaddr': 'docker-server', 'port': 22001, 'load_factors': {}, 'host_key_policy': 'WarningPolicy', } or _remoteagent7 == {'hostname': 'docker-vm-2', 'hostaddr': 'docker-server', 'port': 22002, 'load_factors': {}, 'host_key_policy': 'WarningPolicy', } )
             _session7 = inifile_backend.select_session('testprofile7', 'foo7N')
             self.assertTrue( _session7 == {'port': 22001, 'server': 'docker-server', } or _session7 == {'port': 22001, 'server': 'docker-server', } )
             i += 1
@@ -246,11 +262,31 @@ broker-agent-query-mode = SSH
         i = 0
         while i < 10:
             _remoteagent8 = inifile_backend.get_remote_agent('testprofile8')
-            self.assertTrue( _remoteagent8 == {'hostname': 'docker-vm-0', 'hostaddr': 'docker-server', 'port': 22000, 'load_factors': {}, } or _remoteagent8 == {'hostname': 'docker-vm-1', 'hostaddr': 'docker-server', 'port': 22001, 'load_factors': {}, } or _remoteagent8 == {'hostname': 'docker-vm-2', 'hostaddr': 'docker-server', 'port': 22002, 'load_factors': {}, } )
+            self.assertTrue( _remoteagent8 == {'hostname': 'docker-vm-0', 'hostaddr': 'docker-server', 'port': 22000, 'load_factors': {}, 'host_key_policy': 'WarningPolicy', } or _remoteagent8 == {'hostname': 'docker-vm-1', 'hostaddr': 'docker-server', 'port': 22001, 'load_factors': {}, 'host_key_policy': 'WarningPolicy', } or _remoteagent8 == {'hostname': 'docker-vm-2', 'hostaddr': 'docker-server', 'port': 22002, 'load_factors': {}, 'host_key_policy': 'WarningPolicy', } )
             _session8 = inifile_backend.select_session('testprofile8', 'foo8N')
             self.assertTrue( _session8 == {'port': 22000, 'server': 'docker-server', } or _session8 == {'port': 22001, 'server': 'docker-server', } or _session8 == {'port': 22001, 'server': 'docker-server', } )
             i += 1
 
+        # test "testprofile9", test if hostkey policy is propagated from session profile config to remote agent settings
+
+        _list9 = inifile_backend.list_profiles(username='foo9N')
+        _profile9 = _list9['testprofile9']
+        _profile9['host'].sort()
+        self.assertTrue( _profile9['host'][0] in ('host1.mydomain') )
+        self.assertTrue( 'status' not in _profile9 )
+        _remoteagent9 = inifile_backend.get_remote_agent('testprofile9')
+        self.assertTrue( _remoteagent9 == {'hostname': 'host1.mydomain', 'hostaddr': '10.0.2.4', 'port': 22, 'load_factors': {}, 'host_key_policy': 'AutoAddPolicy'})
+
+        # test "testprofile10", test if an invalid hostkey policy is propagated from session profile config to remote agent settings and ignored with RejectPolicy as fallback
+
+        _list10 = inifile_backend.list_profiles(username='foo10N')
+        _profile10 = _list10['testprofile10']
+        _profile10['host'].sort()
+        self.assertTrue( _profile10['host'][0] in ('host1.mydomain') )
+        self.assertTrue( 'status' not in _profile10 )
+        _remoteagent10 = inifile_backend.get_remote_agent('testprofile10')
+        self.assertTrue( _remoteagent10 == {'hostname': 'host1.mydomain', 'hostaddr': '10.0.2.4', 'port': 22, 'load_factors': {}, 'host_key_policy': 'RejectPolicy'})
+
         x2gobroker.agent._call_local_broker_agent = _save_local_broker_agent_call
         x2gobroker.agent._call_remote_broker_agent = _save_remote_broker_agent_call
         x2gobroker.utils.portscan = _save_portscan
